StreamVideoPushParams class

Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

StreamVideoPushParams({String? id, String? callerName, String? handle, int? type, int? duration, Map<String, dynamic>? extra, Map<String, dynamic>? headers, AndroidParams? android, IOSParams? ios})
const
StreamVideoPushParams.fromJson(Map<String, dynamic> json)
factory
StreamVideoPushParams.fromPushConfiguration(StreamVideoPushConfiguration configuration)
factory

Properties

android AndroidParams?
final
callerName String?
final
duration int?
final
extra Map<String, dynamic>?
final
handle String?
final
hashCode int
The hash code for this object.
no setterinherited
headers Map<String, dynamic>?
final
id String?
final
ios IOSParams?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited